@@ -19,9 +19,7 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-"""This package implements a web server to run scripts or 
-executables from the command line and display the result 
-in a web interface.
+"""This tools run scripts and display the result in a Web Interface.
 
 This file prints an HTML table of user requests."""
 
@@ -30,8 +28,8 @@ __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
 __maintainer_email__ = "mauricelambert434@gmail.com"
-__description__ = """This package implements a web server to run scripts or 
-executables from the command line and display the result in a web interface.
+__description__ = """
+This tools run scripts and display the result in a Web Interface.
 
 This file prints a HTML table of user requests"""
 __license__ = "GPL-3.0 License"
